// Client.java
//
// Informatics 45 Spring 2010
// Code Example: Bytes and Sockets
//
// The client establishes a connection to some address on port 12345 -- for
// testing purposes, I've hard-coded the address "127.0.0.1," which is an
// address that always refers to the current machine you're on -- then sends
// it 85,000 randomly-chosen bytes.  It then sums up the 85,000 bytes and
// prints their sum.  Compare the sum that the client prints out to the sum
// that the server prints out to see if they both print out the same sum.

package inf45.spring2010.examples.sockets4;

import java.net.Socket;
import java.util.Random;


public class Client
{
	private static final int BYTE_COUNT = 85000;
	
	
	public static void main(String[] args)
	throws Exception
	{
		// Here, we generate the array of bytes randomly.  The Random class
		// has a handy method, nextBytes(), which fills any byte[] you give
		// it with randomly-chosen bytes.
		byte[] bytes = new byte[BYTE_COUNT];
		new Random().nextBytes(bytes);

		System.out.println("Establishing connection");

		// Establish a connection to the server.
		Socket socket = new Socket("127.0.0.1", 12345);

		System.out.println("Sending " + BYTE_COUNT + " bytes");
		
		// Send the bytes a chunk at a time.  We're using the same arbitrarily-
		// chosen chunk size of 1024 we used in the server.  Note the use of
		// flush() each time we read a chunk; this is important, so that the
		// data gets sent immediately.
		int offset = 0;
		
		while (offset < BYTE_COUNT)
		{
			int chunkSize = Math.min(BYTE_COUNT - offset, 1024);
			socket.getOutputStream().write(bytes, offset, chunkSize);
			socket.getOutputStream().flush();
			offset += chunkSize;
			System.out.println(offset + " bytes written");
		}
		
		socket.close();
		
		// Sum the bytes and print their checksum
		int checksum = 0;
		
		for (int i = 0; i < BYTE_COUNT; i++)
		{
			checksum += bytes[i];
		}
		
		System.out.println("Sent " + BYTE_COUNT + " bytes to server; checksum was " + checksum);
	}
}
