// Server.java
//
// Informatics 45 Spring 2010
// Code Example: Bytes and Sockets
//
// The server waits for a socket connection on port 12345, reads 85,000 bytes
// from the connection, then adds them all up and prints out their sum.
// Compare the sum that the server prints to the sum that the client prints
// to see if they both print the same sum.

package inf45.spring2010.examples.sockets4;

import java.net.ServerSocket;
import java.net.Socket;


public class Server
{
	private static final int BYTE_COUNT = 85000;
	
	
	public static void main(String[] args)
	throws Exception
	{
		System.out.println("Waiting for connection");
		
		// Accept a connection on port 12345
		ServerSocket serverSocket = new ServerSocket(12345);
		Socket socket = serverSocket.accept();

		System.out.println("Reading " + BYTE_COUNT + " bytes");
		
		// arbitrarily chosen a chunk size of 1,024.  The technique here
		// Read 85,000 bytes from it, a chunk at a time.  I've somewhat
		// is very similar to the technique shown in the "read a file into
		// an array of bytes" example.
		byte[] bytes = new byte[BYTE_COUNT];
		
		int offset = 0;
		
		while (offset < BYTE_COUNT)
		{
			// This is a shorthand for finding the smaller of two numbers.
			int chunkSize = Math.min(BYTE_COUNT - offset, 1024);
			offset += socket.getInputStream().read(bytes, offset, chunkSize);
			System.out.println(offset + " bytes read");
		}
		
		socket.close();
		
		int checksum = 0;
		
		for (int i = 0; i < BYTE_COUNT; i++)
		{
			checksum += bytes[i];
		}
		
		System.out.println("Received " + BYTE_COUNT + " bytes; the checksum is " + checksum);
	}
}
